List:Internals« Previous MessageNext Message »
From:reggie Date:June 2 2005 8:54pm
Subject:bk commit into 4.1 tree (reggie:1.2307)
View as plain text  
Below is the list of changes that have just been committed into a local
4.1 repository of . When  does a push these changes will
be propagated to the main repository and, within 24 hours after the
push, to the public repository.
For information on how to access the public repository
see http://dev.mysql.com/doc/mysql/en/installing-source-tree.html

ChangeSet
  1.2307 05/06/02 13:54:27 reggie@monster. +1 -0
  remove the sharing bit before attempting to compute the mode string.  Without removing 
  this bit, then none of the if statements following match
  and the default mode string of w+ is used, even if the mode requested should be "r".
  
  This was potentially a very dangerous bug.

  mysys/my_fopen.c
    1.13 05/06/02 13:54:23 reggie@monster. +1 -1
    remove the sharing bit before attempting to compute the mode string.  Without removing

    this bit, then none of the if statements following match
    and the default mode string of w+ is used, even if the mode requested should be "r".

# This is a BitKeeper patch.  What follows are the unified diffs for the
# set of deltas contained in the patch.  The rest of the patch, the part
# that BitKeeper cares about, is below these diffs.
# User:	reggie
# Host:	monster.
# Root:	D:/Work/mysql-4.1

--- 1.12/mysys/my_fopen.c	2005-05-25 04:56:41 -05:00
+++ 1.13/mysys/my_fopen.c	2005-06-02 13:54:23 -05:00
@@ -166,7 +166,7 @@
 #if FILE_BINARY					/* If we have binary-files */
   reg3 int org_flag=flag;
 #endif
-  flag&= ~FILE_BINARY;				/* remove binary bit */
+  flag&= ~(FILE_BINARY|O_SHARE);				/* remove binary and share bits */
   if (flag == O_RDONLY)
     *to++= 'r';
   else if (flag == O_WRONLY)

Thread
bk commit into 4.1 tree (reggie:1.2307)reggie2 Jun